# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.1](https://github.com/lox-space/lox/releases/tag/lox-analysis-v0.1.0-alpha.1) - 2026-03-04

### Added

- *(lox-analysis)* add `lox-analysis` crate

### Other

- *(lox-analysis)* add more tests
- *(lox-analysis)* add body-fixed frame to G/S
- *(lox-analysis)* monomorphize scenarios and analyses
- *(lox-analysis)* use scenario-based analyses
